;; Generated package description from with-command-redo.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "with-command-redo" "0.2.0.20260710.0" "Repeat commands with automatic undo" '((emacs "29.1")) :commit "b3e3c86e2cbeb097552a1bff000905ad28de7907" :authors '(("Campbell Barton" . "ideasman42@gmail.com")) :maintainer '("Campbell Barton" . "ideasman42@gmail.com") :url "https://codeberg.org/ideasman42/emacs-with-command-redo")
